@@ -1,16 +1,10 @@
 from django.conf import settings
 from django.db import models
 from django.db.models import Q
+from django.utils.translation import gettext_lazy as _
 
 from .q_serializer import QSerializer
 
-# django < 1.9 support
-from django import VERSION
-if VERSION >= (2, 0):
-    from django.utils.translation import gettext_lazy as _
-else:
-    from django.utils.translation import ugettext_lazy as _
-
 
 class UserLookupManager(models.Manager):
     def filter_by_user(self, user):
